@@ -1,19 +1,20 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import React from 'react'
 import R from 'ramda'
 import PropTypes from 'prop-types'
-import { DropdownV2 } from 'carbon-components-react'
-import { Tooltip } from '@patternfly/react-core'
+import { AcmDropdown } from '@stolostron/ui-components'
+import { Pagination, Tooltip } from '@patternfly/react-core'
 import { OutlinedQuestionCircleIcon } from '@patternfly/react-icons'
 import msgs from '../../../../nls/platform.properties'
 import _ from 'lodash'
@@ -73,11 +74,11 @@ class ChannelControl extends React.Component {
     )
   }
 
-  handleSubscriptionChange = e => {
-    const channel = e.selectedItem.chn
-    this.changeSubscriptionChannels(channel)
+  handleSubscriptionChange = (e, displayChannels) => {
+    const selectedItem = displayChannels.find(chn => chn.id === e)
+    this.changeSubscriptionChannels(selectedItem.chn)
     // Set the current channel to the selected channel
-    this.setState({ currentChannel: e.selectedItem })
+    this.setState({ currentChannel: selectedItem })
   };
 
   selectChannelByNumber(channelNb) {
@@ -136,21 +137,21 @@ class ChannelControl extends React.Component {
     let mainSubscriptionName //name as showing in the combo; pages from the same subscription share the same main name
 
     Object.values(channelMap).forEach(({ chnl, splitChn, subchannels }) => {
-      const hasSubchannels = subchannels.length > 0
       let channelLabel = splitChn && splitChn[2] ? splitChn[2] : 'unknown'
       if (channelLabel === '__ALL__') {
         channelLabel = msgs.get('combo.subscription.all')
       }
+      const channelID = channelLabel.replace(/\s+/g, '-').toLowerCase()
+
       displayChannels.push({
-        label: channelLabel,
+        id: channelID,
+        text: channelLabel,
         chn: chnl,
-        splitChn,
-        hasSubchannels,
         subchannels
       })
       if (
         chnl === activeChannel ||
-        (hasSubchannels &&
+        (subchannels.length > 0 &&
           subchannels.findIndex(
             ({ chnl: subchannel }) => subchannel === activeChannel
           ) !== -1)
@@ -163,7 +164,7 @@ class ChannelControl extends React.Component {
       displayChannels.length === 1 || !mainSubscriptionName
         ? 0
         : displayChannels.findIndex(
-          ({ label }) => label === mainSubscriptionName
+          ({ text }) => text === mainSubscriptionName
         )
     if (selectedIdx < 0) {
       selectedIdx = displayChannels.findIndex(({ chn }) => !!chn)
@@ -255,7 +256,7 @@ class ChannelControl extends React.Component {
     return { selectedSubscription, selectedPageForCurrentSubs }
   };
 
-  handlePageClick = e => {
+  handlePagination = (e, action, pageLimit) => {
     const { channelControl = {} } = this.props
     const {
       selectedSubscription,
@@ -267,15 +268,22 @@ class ChannelControl extends React.Component {
       return
     }
     let newPageSelection = null
-    switch (e.target.id) {
-    case 'p1': {
+    switch (action) {
+    case 'input': {
+      if (e.target.value > 0 && e.target.value <= pageLimit) {
+        newPageSelection =
+            selectedSubscription.subchannels[e.target.value - 1]
+      }
+      break
+    }
+    case 'first': {
       //move to the first page
       if (selectedSubscription.subchannels.length > 0) {
         newPageSelection = selectedSubscription.subchannels[0]
       }
       break
     }
-    case 'p2': {
+    case 'prev': {
       //move one page down
       if (
         selectedSubscription.subchannels.length > 0 &&
@@ -286,7 +294,7 @@ class ChannelControl extends React.Component {
       }
       break
     }
-    case 'p3': {
+    case 'next': {
       //move one page up
       if (
         selectedSubscription.subchannels.length > selectedPageForCurrentSubs
@@ -296,7 +304,7 @@ class ChannelControl extends React.Component {
       }
       break
     }
-    case 'p4': {
+    case 'last': {
       //up to the last page
       if (selectedSubscription.subchannels.length > 0) {
         newPageSelection =
@@ -331,12 +339,7 @@ class ChannelControl extends React.Component {
       let selectedChannelIndex = 0
       let displayChannels = []
       let isRefreshing = true
-
-      const comboLabel = msgs.get('combo.subscription.choose', locale)
-      const back1 = '<<'
-      const back2 = '<'
-      const fwd1 = '>'
-      const fwd2 = '>>'
+      const maxNodesPerPage = 100
 
       if (allChannels.length > 1) {
         // Update channel control variables for when refresh state is done
@@ -355,7 +358,7 @@ class ChannelControl extends React.Component {
         const selectedIdx = channelsData[1]
 
         selectedSubscriptionIsPaged =
-          displayChannels[selectedIdx].hasSubchannels
+          displayChannels[selectedIdx].subchannels.length > 0
         selectedSubscriptionPages = selectedSubscriptionIsPaged
           ? displayChannels[selectedIdx].subchannels.length
           : 0
@@ -372,7 +375,14 @@ class ChannelControl extends React.Component {
 
       return (
         // show subscription names only when more than one
-        <div className="channel-controls-container">
+        <div
+          className="channel-controls-container"
+          style={
+            selectedSubscriptionIsPaged
+              ? { height: '174px' }
+              : { height: '150px' }
+          }
+        >
           {showMainChannel && (
             <div className="channels">
               <div className="subscription label">
@@ -391,15 +401,17 @@ class ChannelControl extends React.Component {
               </div>
 
               <div className="channelsCombo">
-                <DropdownV2
-                  items={displayChannels}
+                <AcmDropdown
+                  isDisabled={isRefreshing}
                   id="comboChannel"
-                  label={comboLabel}
-                  ariaLabel={comboLabel}
-                  inline={true}
-                  onChange={this.handleSubscriptionChange}
-                  selectedItem={currentChannel}
-                  disabled={isRefreshing}
+                  onSelect={e =>
+                    this.handleSubscriptionChange(e, displayChannels)
+                  }
+                  text={currentChannel.text}
+                  dropdownItems={displayChannels}
+                  position="left"
+                  isPlain={false}
+                  isPrimary={false}
                 />
               </div>
             </div>
@@ -422,63 +434,18 @@ class ChannelControl extends React.Component {
                 </div>
               </div>
               <div className="mainPagination">
-                <span
-                  id="p1"
-                  role="button"
-                  className="label pageLabel labelLink"
-                  onClick={this.handlePageClick}
-                  onKeyPress={this.handlePageClick}
-                  tabIndex="0"
-                >
-                  {back1}
-                </span>
-                <span
-                  id="p2"
-                  role="button"
-                  className="label pageLabel labelLink"
-                  onClick={this.handlePageClick}
-                  onKeyPress={this.handlePageClick}
-                  tabIndex="0"
-                >
-                  {back2}
-                </span>
-                <input
-                  className="label pageInput"
-                  id="valuePage"
-                  onChange={this.handlePageClick}
-                  onKeyPress={this.handlePageClick}
-                  aria-label="Current page"
-                  type="number"
-                  min="1"
-                  max="{selectedSubscriptionPages}"
-                  value={selectedChannelIndex}
-                  tabIndex="0"
+                <Pagination
+                  itemCount={selectedSubscriptionPages * maxNodesPerPage}
+                  perPage={maxNodesPerPage}
+                  page={selectedChannelIndex}
+                  onFirstClick={e => this.handlePagination(e, 'first')}
+                  onLastClick={e => this.handlePagination(e, 'last')}
+                  onNextClick={e => this.handlePagination(e, 'next')}
+                  onPreviousClick={e => this.handlePagination(e, 'prev')}
+                  onPageInput={e =>
+                    this.handlePagination(e, 'input', selectedSubscriptionPages)
+                  }
                 />
-                <span className="label pageLabel">
-                  {msgs.get('subscription.page.nb', [
-                    selectedSubscriptionPages
-                  ])}
-                </span>
-                <span
-                  id="p3"
-                  role="button"
-                  className="label pageLabel labelLink"
-                  onClick={this.handlePageClick}
-                  onKeyPress={this.handlePageClick}
-                  tabIndex="0"
-                >
-                  {fwd1}
-                </span>
-                <span
-                  id="p4"
-                  role="button"
-                  className="label pageLabel labelLink"
-                  onClick={this.handlePageClick}
-                  onKeyPress={this.handlePageClick}
-                  tabIndex="0"
-                >
-                  {fwd2}
-                </span>
               </div>
             </div>
           )}
@@ -488,31 +455,6 @@ class ChannelControl extends React.Component {
     return null
   }
 
-  renderView({ style, ...props }) {
-    style.marginBottom = -17
-    return <div {...props} style={{ ...style }} />
-  }
-
-  renderThumbHorizontal() {
-    return <div />
-  }
-
-  renderThumbVertical({ style, ...props }) {
-    const finalStyle = {
-      ...style,
-      cursor: 'pointer',
-      borderRadius: 'inherit',
-      backgroundColor: 'rgba(0,0,0,.2)'
-    }
-    return (
-      <div
-        className={'channel-controls-scrollbar'}
-        style={finalStyle}
-        {...props}
-      />
-    )
-  }
-
   changeSubscriptionChannels(fetchChannel) {
     const { channelControl = {} } = this.props
     const { changeTheChannel } = channelControl
